addImageSource method

Future<void> addImageSource(
  1. String name,
  2. Uint8List bytes,
  3. LatLngQuad coordinates
)

Adds an image source to the style currently displayed in the map, so that it can later be referred to by the provided name.

Implementation

Future<void> addImageSource(
    String name, Uint8List bytes, LatLngQuad coordinates) {
  return MapboxGlPlatform.getInstance(_id)!
      .addImageSource(name, bytes, coordinates);
}