addImageSource method
Adds an image source to the style currently displayed in the map, so that it can later be referred to by the provided name.
Implementation
Future<void> addImageSource(
String name, Uint8List bytes, LatLngQuad coordinates) {
return MapboxGlPlatform.getInstance(_id)!
.addImageSource(name, bytes, coordinates);
}